@@ -8,7 +8,7 @@ import joblib
 warnings.filterwarnings("ignore")
 
 W2V_MODEL_PATH = "data/word2vec_wx"
-XG_MODEL_PATH = "data/2020_08_05_18_08_danmu_XG.model"
+XG_MODEL_PATH = "2020_08_05_18_08_danmu_XG.model"
 
 
 class XgWord2Vec(object):
@@ -33,7 +33,7 @@ class XgWord2Vec(object):
 
 if __name__ == '__main__':
     t = time.time()
-    sg = XgWord2Vec("data/2020_08_05_18_08_danmu_XG.model")
+    sg = XgWord2Vec("2020_08_05_18_08_danmu_XG.model")
     # joblib.dump(sg, "20200806_model.cls")
     # model = joblib.load("20200806_model.cls")
     # print(model.predict("你喜欢我吗"))
